#include <xc.h>

void InitPWM( void)
{
    // init TMR3 to provide the timebase
    T3CON = 0x8000;         // enable TMR3,  1:1, int clock
    PR3 = 1024-1;           // set period for given bitrate
    _T3IF = 0;              // clear interrupt flag
    _T3IE = 0;              // disable TMR3 interrupt

    // init PWM
    // set the initial duty cycles
    OC1R = OC1RS = 100;     // 

    // activate the PWM modules 
    OC1CON = 0x000E;        

} //

void _ISRFAST _T3Interrupt( void)
{
    // clear interrupt flag and exit
    _T3IF = 0;
} // T3 Interrupt

void _ISR _INT1Interrupt( void)
{

	PORTBbits.RB10 = 1;

	while(PORTA != 0x0000) //if PORTA = 11, 10, 01 just wait
	{
		//wait for PORTA == 00;
	}
	//Now PORTA == 00

	while (PORTA ==	0x0000)
	{
		//Wait for PORTA to become 10 OR 11 OR 01.
	}
	//Now PORTA == 00, 01, 10

	if (PORTA == 0x0002) 	//10
	{
		//lagging for example
		OC1R--;
		if(OC1R <= 10)
			OC1R = 10;
	}
		
	
	else if(PORTA == 0x0001)  //01
	{
		//leading for example
		OC1R++;		
		if(OC1R >= 1000)
			OC1R = 1000;
	}

	else						//11
	{
		//OK, do nothing
	}		
	
 	PORTBbits.RB10 = 0;

 	IFS1bits.INT1IF = 0; //clear INT0 interrupt flag
}

main( void)
{ 
 	//Set Oscillator Configuration------------------------------------------
 	OSCCON = 0x0100; //0000000100000000 Fast RC Oscillator (FRC) with divide-by-N and PLL (FRCDIVN + PLL) 
 	CLKDIV = 0x0000; //
 	PLLFBD = 0x002A; //7.37 MHZ internal FRC oscillator /44 set to 42==>2A @ 40.535 MIPS
 	//----------------------------------------------------------------------

 	TRISBbits.TRISB10 = 0; 	//All outputs
	TRISA = 0x0003;			//0000000000000011 RA0 and RA1 are inputs

 	//setup external INT1---------------------------------------------------
 	INTCON2 = 0x0000; 		//set up INT1 on rising edge 
   	IFS1bits.INT1IF = 0; 	//reset INT1 interrupt flag
   	IEC1bits.INT1IE = 1; 	//enable INT1 ISR
   	IPC5bits.INT1IP = 7; 	//set highest priority

 	//diable analog functions on AN pins------------------------------------
	PMD1bits.AD1MD 	= 1;	//ADC disabled
	//disable change notification-------------------------------------------
	CNPU1 = 0;				//All pull-ups disabled
		
 	//unlock peripheral select----------------------------------------------
 	OSCCON = 0x46;
 	OSCCON = 0x57;
 	OSCCONbits.IOLOCK = 0;
 	RPINR0bits.INT1R  = 8; 		// Tie INT1 to RP8 pin 17
	RPOR3bits.RP6R	  =0b10010; //Tie OC1 to RP6
 	OSCCONbits.IOLOCK = 1;

	InitPWM();					//Initialize PWM system

    while(1)
 	{
	}

}// main

 